DocuTranslate - 交互式文档翻译

#### DocuTranslate

##

解析引擎
Mineru Token

##

选择平台
API 地址 (Base URL)
API Key
模型 ID

##

目标语言
自定义Prompt
公式识别
代码识别
Markdown修复

##

分块大小:
并发数:
Temperature:

GitHub主页(欢迎star❤):
https://github.com/xunbu/docutranslate

交流QQ群: 1047781902

#### 任务列表

当前没有任务，点击“新建任务”开始吧！

##### 预览

###### 原文

###### 译文

##### 使用教程

视频教程可以在b站搜索 docutranslate 获取

欢迎使用 DocuTranslate！请按照以下步骤完成文档翻译：

1. 配置参数

   在左侧的配置面板中，完成以下设置：

   - 解析配置:
     - 选择一个解析引擎。推荐使用 `minerU` 进行云端解析（支持PDF/Word/PPT/jpg等），如果需要本地解析，可以选择 `Docling`。
     - 如果使用 `minerU`，请填入您的 Mineru Token。
     - 如果输入文件是txt或markdown文件，该部分可以不进行设置
   - 翻译模型:
     - 选择您的AI服务提供商平台，或选择 `自定义接口`。
     - 填入您的 `API Key` 和 `模型 ID`（例如 glm-4-flash、deepseek-chat）。
     - API-KEY和模型ID参见对应平台文档。
     - 建议使用非推理模型进行翻译。
   - 翻译配置:
     - 选择您希望翻译的 目标语言。
     - 可以填写自定义Prompt，指导AI进行特定翻译，例如“人名保持原文不翻译”。
   - 高级参数:
     - 通常保持默认即可。
     - 并发数指的是每个任务允许多少个并发AI翻译请求，需参照平台模型速率限制进行设置
2. 上传文件

   在右侧的任务列表中，点击或拖拽您的文档（如PDF, Markdown等）到文件上传区域。

3. 开始翻译

   文件选择成功后，点击任务卡片右下角的 开始翻译 按钮。系统将开始处理任务，您可以在日志区域查看实时进度。

4. 查看与下载

   翻译完成后，任务卡片下方会出现操作按钮：

   - 预览: 在右侧滑出的面板中进行原文和译文的对照预览。
   - 下载 PDF: 将译文直接保存为PDF格式。
   - 下载其他格式: 下载HTML或Markdown格式的译文。

提示: 所有配置都会自动保存在您的浏览器本地，方便下次使用。

##### 感谢贡献

DocuTranslate是一个开源项目！大家的需求与使用是项目进步的动力。

感谢所有资助项目、提交代码与宝贵建议及给项目star的朋友们！

欢迎通过以下方式参与贡献：

github 主页 提交 Pull Request 报告 Issue

或者通过QQ群联系作者：1047781902